"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShikiProvider = ShikiProvider;
exports.useShiki = useShiki;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = require("react");
var _jsxRuntime = require("react/jsx-runtime");
/* eslint-disable no-console */

const DEBUG = true;
function _log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/(0, _react.createContext)(null);
function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = (0, _react.useState)(null);
  const [isReady, setIsReady] = (0, _react.useState)(false);
  const [error, setError] = (0, _react.useState)(null);
  (0, _react.useEffect)(() => {
    const initHighlighter = async () => {
      try {
        if (!initialThemes.length) {
          throw new Error('At least one theme must be provided');
        }

        // Get the first theme and ensure it exists
        const defaultTheme = initialThemes[0];
        if (!defaultTheme || !defaultTheme.name) {
          throw new Error('Invalid theme format');
        }
        _log('Using theme:', {
          name: defaultTheme.name,
          type: defaultTheme.type,
          tokenColors: defaultTheme.tokenColors?.length,
          colors: Object.keys(defaultTheme.colors || {}).length
        });

        // Create highlighter with initial settings
        const highlighterInstance = await (0, _core.createHighlighterCore)({
          themes: [defaultTheme],
          // Pass as array
          langs: initialLanguages,
          engine: (0, _engineJavascript.createJavaScriptRegexEngine)({
            forgiving: true,
            cache: new Map()
          })
        });

        // Set the theme
        const themeName = defaultTheme.name;
        highlighterInstance.setTheme(themeName);
        _log('Theme loaded:', {
          name: themeName,
          loadedThemes: highlighterInstance.getLoadedThemes()
        });
        _log('Initialization complete', {
          languages: highlighterInstance.getLoadedLanguages(),
          themes: highlighterInstance.getLoadedThemes()
        });
        setHighlighter(highlighterInstance);
        setIsReady(true);
        setError(null);
      } catch (err) {
        console.error('Highlighter initialization failed:', err);
        setError(err instanceof Error ? err : new Error('Initialization failed'));
        setIsReady(false);
      }
    };
    initHighlighter();
  }, [initialLanguages, initialThemes]);
  const value = (0, _react.useMemo)(() => ({
    highlighter,
    isReady,
    error
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
function useShiki() {
  const context = (0, _react.useContext)(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map